/*==============================================================*/
/* Table: PFIFlight                                             */
/*==============================================================*/
create table PFIFlight
(
   mulFlightId                    int                            not null,
   mulAirlineId                   int                            not null,
   msFlightNo                     varchar(15)                    not null,
   msAirportOfDeparture           varchar(5)                     not null,
   msArrivalAirport               varchar(5)                     not null,
   msACModelCode                  varchar(6)                     not null,
   msACRegCode                    varchar(15),
   mdtSTD                         datetime,
   mdtETD                         datetime,
   mdtATD                         datetime,
   mdtDoorClosed                  datetime,
   mdtBlocksOff                   datetime,
   mdtSTA                         datetime,
   mdtETA                         datetime,
   mdtETA2                        datetime,
   mdtATA                         datetime,
   mdtDoorOpen                    datetime,
   mdtBlocksOn                    datetime,
   mdtCTOT                        datetime,
   mdtEET                         datetime,
   mdtLatestArr                   datetime,
   mdtLatestDep                   datetime,
   muhFlightLoadType              tinyint,
   muiFlightType                  smallint,
   muhFlightScheduleType          tinyint,
   mbDomestic                     bool                           not null,
   mulType                        int,
   mulDepPlanId                   int,
   mulArrPlanId                   int,
   mulInsUserId                   int                            not null,
   mdtInsTime                     datetime                       not null,
   mulUpdUserId                   int,
   mdtUpdTime                     datetime,
   muiProcessId                   smallint                       not null,
   muhStateId                     tinyint                        not null,
   mulUpdCnt                      int                            not null,
   mulSrvUpdCnt                   int                            not null,
   primary key (mulFlightId)
)
type = InnoDB;

/*==============================================================*/
/* Index: ndx_arr_range                                         */
/*==============================================================*/
create unique index ndx_arr_range on PFIFlight
(
   mdtLatestArr,
   msArrivalAirport,
   mulAirlineId,
   msACRegCode,
   muhFlightLoadType,
   mulFlightId
);

/*==============================================================*/
/* Index: ndx_dep_range                                         */
/*==============================================================*/
create unique index ndx_dep_range on PFIFlight
(
   mdtLatestDep,
   msAirportOfDeparture,
   mulAirlineId,
   msACRegCode,
   muhFlightLoadType,
   mulFlightId
);

/*==============================================================*/
/* Index: ndx_arr_merge                                         */
/*==============================================================*/
create index ndx_arr_merge on PFIFlight
(
   msACRegCode,
   msArrivalAirport,
   mulAirlineId,
   mdtLatestArr,
   mulFlightId
);

/*==============================================================*/
/* Index: ndx_dep_merge                                         */
/*==============================================================*/
create index ndx_dep_merge on PFIFlight
(
   msACRegCode,
   msAirportOfDeparture,
   mulAirlineId,
   mdtLatestDep,
   mulFlightId
);


/*==============================================================*/
/* Table: PFILanded                                             */
/*==============================================================*/
create table PFILanded
(
   mulLandedId                    int                            not null,
   msArrFrom                      varchar(5),
   msAirportCode                  varchar(5)                     not null,
   msDepTo                        varchar(5),
   msParkPosCode                  varchar(10),
   msParkAreaCode                 varchar(10),
   msGate                         varchar(10),
   mulAirlineId                   int                            not null,
   mulArrFlightId                 int,
   mulDepFlightId                 int,
   mulType                        int,
   mulFlightPlanId                int,
   mulReprId                      int,
   mdtSlotBegin                   datetime,
   mdtSlotEnd                     datetime,
   muiProcessId                   smallint                       not null,
   muhStateId                     tinyint                        not null,
   mulUpdUserId                   int,
   mdtUpdTime                     datetime,
   mulInsUserId                   int                            not null,
   mdtInsTime                     datetime                       not null,
   mulUpdCnt                      int                            not null,
   mulSrvUpdCnt                   int                            not null,
   primary key (mulLandedId)
)
type = InnoDB;

/*==============================================================*/
/* Index: "Landed_2_Flight1_FK"                                            */
/*==============================================================*/
create index Landed_2_Flight1_FK on PFILanded
(
   mulArrFlightId
);

/*==============================================================*/
/* Index: "Landed_2_Flight2_FK"                                            */
/*==============================================================*/
create index Landed_2_Flight2_FK on PFILanded
(
   mulDepFlightId
);

/*==============================================================*/
/* Index: ndx_arr                                               */
/*==============================================================*/
create index ndx_arr on PFILanded
(
   mulArrFlightId,
   muhStateId,
   mulLandedId
);

/*==============================================================*/
/* Index: ndx_dep                                               */
/*==============================================================*/
create index ndx_dep on PFILanded
(
   mulDepFlightId,
   muhStateId,
   mulLandedId
);

/*==============================================================*/
/* Index: ndx_main                                              */
/*==============================================================*/
create unique index ndx_main on PFILanded
(
   msAirportCode,
   mulAirlineId,
   mulLandedId
);

/*==============================================================*/
/* Table: PFILandedCompany                                      */
/*==============================================================*/
create table PFILandedCompany
(
   mulLandedId                    int                            not null,
   mulCompanyId                   int                            not null,
   msAirportCode                  varchar(5)                     not null,
   mulUpdUserId                   int,
   mdtUpdTime                     datetime,
   mulInsUserId                   int                            not null,
   mdtInsTime                     datetime                       not null,
   mulUpdCnt                      int                            not null,
   mulSrvUpdCnt                   int                            not null,
   primary key (mulLandedId, mulCompanyId)
)
comment = "This landed is known to be served by the defined companies of that airport in this table."
type = InnoDB;

/*==============================================================*/
/* Index: "LandedCompany_2_Landed_FK"                                            */
/*==============================================================*/
create index LandedCompany_2_Landed_FK on PFILandedCompany
(
   mulLandedId
);

/* insert the data  */

INSERT INTO PFIFlight VALUES (
	196754,
	2166,
	'1',
	'ESB',
	'IST',
	'M83',
	'TC-AKL',
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	{ts '2010-06-20 06:00:00.000000'},
	NULL,
	NULL,
	{ts '2010-06-20 06:00:00.000000'},
	NULL,
	{ts '2010-06-20 06:05:00.000000'},
	NULL,
	NULL,
	{ts '2010-06-20 06:00:00.000000'},
	NULL,
	1,
	1,
	1,
	1,
	NULL,
	NULL,
	NULL,
	27,
	{ts '2005-06-20 18:47:27.000000'},
	NULL,
	NULL,
	18,
	1,
	0,
	1);
INSERT INTO PFIFlight VALUES (
	196755,
	2166,
	'2',
	'ADB',
	'IST',
	'M83',
	'TC-AKL',
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	{ts '2010-06-20 11:00:00.000000'},
	NULL,
	NULL,
	{ts '2010-06-20 11:00:00.000000'},
	NULL,
	{ts '2010-06-20 11:05:00.000000'},
	NULL,
	NULL,
	{ts '2010-06-20 11:00:00.000000'},
	NULL,
	1,
	1,
	1,
	1,
	NULL,
	NULL,
	NULL,
	27,
	{ts '2005-06-20 18:48:10.000000'},
	NULL,
	NULL,
	18,
	1,
	0,
	1);
INSERT INTO PFIFlight VALUES (
	196758,
	2166,
	'5',
	'ESB',
	'IST',
	'M83',
	'TC-AKL',
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	{ts '2010-06-20 23:00:00.000000'},
	NULL,
	NULL,
	{ts '2010-06-20 22:55:00.000000'},
	{ts '2010-06-20 23:05:00.000000'},
	{ts '2010-06-20 23:00:00.000000'},
	NULL,
	NULL,
	{ts '2010-06-20 22:55:00.000000'},
	NULL,
	1,
	1,
	1,
	1,
	NULL,
	NULL,
	NULL,
	27,
	{ts '2005-06-20 19:25:01.000000'},
	NULL,
	NULL,
	18,
	1,
	0,
	1);
INSERT INTO PFIFlight VALUES (
	196756,
	2166,
	'3',
	'IST',
	'ADB',
	'M83',
	'TC-AKL',
	{ts '2010-06-20 12:00:00.000000'},
	NULL,
	{ts '2010-06-20 12:05:00.000000'},
	NULL,
	{ts '2010-06-20 12:00:00.000000'},
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	{ts '2010-06-20 12:05:00.000000'},
	1,
	1,
	1,
	1,
	NULL,
	NULL,
	NULL,
	27,
	{ts '2005-06-20 18:49:06.000000'},
	NULL,
	NULL,
	18,
	1,
	0,
	1);
INSERT INTO PFIFlight VALUES (
	196757,
	2166,
	'4',
	'IST',
	'ESB',
	'M83',
	'TC-AKL',
	{ts '2010-06-20 21:00:00.000000'},
	NULL,
	{ts '2010-06-20 21:15:00.000000'},
	NULL,
	{ts '2010-06-20 21:00:00.000000'},
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	{ts '2010-06-20 21:15:00.000000'},
	1,
	1,
	1,
	1,
	NULL,
	NULL,
	NULL,
	27,
	{ts '2005-06-20 18:49:44.000000'},
	NULL,
	NULL,
	18,
	1,
	0,
	1);
INSERT INTO PFIFlight VALUES (
	196759,
	2166,
	'6',
	'IST',
	'ESB',
	'M83',
	'TC-AKL',
	{ts '2010-06-20 23:45:00.000000'},
	NULL,
	{ts '2010-06-20 23:45:00.000000'},
	NULL,
	{ts '2010-06-20 23:40:00.000000'},
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	{ts '2010-06-20 23:45:00.000000'},
	1,
	1,
	1,
	1,
	NULL,
	NULL,
	NULL,
	27,
	{ts '2005-06-20 19:25:01.000000'},
	NULL,
	NULL,
	18,
	1,
	0,
	1);

INSERT INTO PFILanded VALUES (
	158239,
	NULL,
	'IST',
	NULL,
	NULL,
	NULL,
	NULL,
	2166,
	196754,
	NULL,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	19,
	1,
	NULL,
	NULL,
	27,
	{ts '2005-06-20 18:47:29.000000'},
	0,
	1);
INSERT INTO PFILanded VALUES (
	158240,
	'SZF',
	'IST',
	NULL,
	NULL,
	NULL,
	NULL,
	2166,
	196755,
	NULL,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	19,
	1,
	27,
	{ts '2005-06-20 21:58:44.000000'},
	27,
	{ts '2005-06-20 18:48:10.000000'},
	1,
	2);
INSERT INTO PFILanded VALUES (
	158243,
	NULL,
	'IST',
	NULL,
	NULL,
	NULL,
	NULL,
	2166,
	196758,
	196759,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	19,
	1,
	NULL,
	NULL,
	27,
	{ts '2005-06-20 19:25:01.000000'},
	0,
	1);
INSERT INTO PFILanded VALUES (
	158241,
	NULL,
	'IST',
	NULL,
	NULL,
	NULL,
	NULL,
	2166,
	NULL,
	196756,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	19,
	1,
	NULL,
	NULL,
	27,
	{ts '2005-06-20 18:49:06.000000'},
	0,
	1);
INSERT INTO PFILanded VALUES (
	158242,
	NULL,
	'IST',
	NULL,
	NULL,
	NULL,
	NULL,
	2166,
	NULL,
	196757,
	0,
	NULL,
	NULL,
	NULL,
	NULL,
	19,
	1,
	NULL,
	NULL,
	27,
	{ts '2005-06-20 18:49:44.000000'},
	0,
	1);

INSERT INTO PFILandedCompany VALUES (
	158239,
	1,
	'IST',
	NULL,
	NULL,
	27,
	{ts '2005-06-20 18:47:29.000000'},
	0,
	1);
INSERT INTO PFILandedCompany VALUES (
	158240,
	1,
	'IST',
	NULL,
	NULL,
	27,
	{ts '2005-06-20 18:48:10.000000'},
	0,
	1);
INSERT INTO PFILandedCompany VALUES (
	158243,
	1,
	'IST',
	NULL,
	NULL,
	27,
	{ts '2005-06-20 19:25:01.000000'},
	0,
	1);
INSERT INTO PFILandedCompany VALUES (
	158241,
	1,
	'IST',
	NULL,
	NULL,
	27,
	{ts '2005-06-20 18:49:06.000000'},
	0,
	1);
INSERT INTO PFILandedCompany VALUES (
	158242,
	1,
	'IST',
	NULL,
	NULL,
	27,
	{ts '2005-06-20 18:49:44.000000'},
	0,
	1);
